function [LdB,delta,E]=LambdaDB(E,m,Ep)
% LambdaDB calculates the de Broglie wavelength of a physical object using its 
%  energy, its mass, and the various potential energy values Ep(i) (i=1,2,...). 
%   The penetration depth (delta) in a region where the potential energy is 
%   greater than the physical object energy is also given.
% 
%   [LdB,delta,E]=LambdaDB(E,m,Ep)
%       >> E        = Physical object energy (eV)
%       >> m        = Physical object mass (with respect to electron mass)
%       >> Ep       = Potential energy Ep(i) (eV)
%       << LdB      = De Broglie wavelength LdB(i) (nm)
%       << delta    = Penetration depth delta(i) (nm)
%	  << E
%                           
%   Olivier Pujol (2010)
%    
%% Verifications

if (m<=0), error('La masse doit tre strictement positive !');end

% Verification that any E-value is equal to an Ep-value
for i=1:length(Ep)
    Ind=(abs(E-Ep(i))<eps); % Finding E-values for which E=Ep
    E=E(Ind~=1);            % Previous values are not kept
end

clear i Ind

%% Computing of LDB and Delta

LdB=cell(size(E));
delta=cell(size(E));
k=cell(size(E));
%
for n=1:length(E)
    k{n}=WaveVect(E(n),m,Ep);
        
    Ind=nan(1,length(k{n}));
    
    for ik=1:length(k{n}) 
        Ind(ik)=isreal(k{n}(ik));
    end

    LdB{n}=nan(1,length(k{n}));
    LdB{n}(Ind==1)=2*pi./(k{n}(Ind==1));
    delta{n}=nan(1,length(k{n}));
    delta{n}(Ind==0)=1./(2*imag(k{n}(Ind==0)));
    
end
%
if (length(E)==1)
    LdB=LdB{1};
    delta=delta{1};
end

return;