function [sys,E]=Morse(Ep0,x0,a,m,varargin)
% MORSE gives the bound state energies of a physical object which interacts 
%  with a Morse potential energy.
%
%   [sys,E]=Morse(Ep0,x0,a,m,varargin) 
%					-- varargin states for various input arguments
%   	>> Ep0          = Well depth (eV)
%   	>> x0           = Position of the well minimum
%   	>> a            = Characteristic constant (m^{-1})
%   	>> m            = Physical object mass (with respect to mass electron)
%   	>> varargin     = Optional input arguments
%           >> nx     	= Gate number on Ox (default value: 200)
%           >> nE     	= Number of energy values (default: 1000)
%           >> Emin   	= Lowest energy value (default: min(Ep))
%           >> Emax   	= Highest energy value (default: 0)
%
% Olivier Pujol (2010)

%% Verifications

if (Ep0<=0),error('One must have Ep0 > 0');end
if (x0<=0),error('One must have x0 > 0');end
if (m<=0),error('One must have m > 0');end

%% Optional input arguments

switch length(varargin)
    case 0
        nx=200;                     % Default value of Ox gate number
        nE=1000;                    % Default value of energy values number
    case 1
        nx=varargin{1};             % Default value of Ox gate number
        nE=1000;                    % Default value of energy values number
    case 2
        nx=varargin{1};             % Default value of Ox gate number
        nE=varargin{2};             % Default value of energy values number
    case 4
        nx=varargin{1};             % Value of Ox gate number
        nE=varargin{2};             % Value of energy values number
        E=linspace(varargin{3},varargin{4},nE);              % Set of energy values
    otherwise
        ('Bad number of optional input arguments');
end

%% Well bounds determination

% Potential energy is theoretically infinite at x=0. Thus,  
% the lower limit of the well is chosen such that Ep = n*Ep0 (n=10).
% User can change this value. 

n=10;
xA=x0-(1/a)*log(1+(n)^0.5);
clear n

% Potential energy is theoretically is zero if x goes to infinity. Thus, 
% the higher limit is chosen such that Ep = epsilon*Ep0 (epsilon=0.001).
% User can change this value. 
epsilon = 0.001;
xB=x0-(1/a)*log(1-(1-epsilon)^0.5);
clear epsilon

if (xA>=x0),error('The lower limit of the well is greater than x0');end
if (xB<=x0),error('The higher limit of the well is lower than x0');end
if (xA>=xB),error('The lower limit of the wel is greater than its higher limit');end

%% Potential energy

% Construction
x=linspace(xA,xB,nx);                % Spatial domain 
Epc=Ep0*(1-exp(-a*(x-x0))).^2;       % Potential energy of Morse (Morse 1929). Origin is at minimum

% Digitalization
[M,xt,Ep]=digitalization(x,Epc); 	% Digitalization
axis([0 xB 0 Ep0]);            		% Plotting aspect

% Energy values
if (length(varargin)~=4)
    E=linspace(min(Ep),Ep0,nE);   % Set of energy values
end    

if (min(E)<0 || max(E)>Ep0),error('Some energy values are out of bound state domain');end

%% Bound states

[sys,E]=Epot(M,xt,Ep,m,E);          % System 
sysconf(sys,E);                     % Bound states

return;