function [sys,E,Ep]=ramp(Epi,Epf,slope,m,varargin)
% RAMP returns the reflection and transmission probabilities  
%   for a ramp of potential energy with a given inclination and proposes a   
%   graphical representation versus the energy of the physical object.
%
%	[sys,E,Ep]=ramp(Epi,Epif,pendiente,m,varargin) -- varargin states for various input arguments
%
%   	>> slope  		= Slope of the ramp of potential energy (J/m)
%   	>> m        	= Physical object mass (with respect to electron mass)
%   	>> varargin 	= Optional input arguments
%           >> nx   	= Gate number on Ox axis (default value: 100)
%           >> nE   	= Number of energy values (default: 1000)
%           >> Emin 	= Lowest energy value (default: min(Ep))
%           >> Emax 	= Highest energy value (default: Ep(max(x)))
%
% Olivier Pujol : septembre 2013

%% Verifications

if (length(varargin)>4), error('Bad number of optional input arguments!');end
if (nargin-length(varargin)~=4),error('Bad number of no optional input arguments!');end
if (abs(slope)<=eps),error('The slope is zero');end

if (slope>0 && Epi>Epf),error('Problem in the energies given');end
if (slope<0 && Epf>Epi),error('Problem in the energies given');end

%% Optional input arguments

switch length(varargin)
    case 0
        nx=100;                     % Default value of Ox gate number
        nE=500;                     % Default value of energy values number
    case 1
        nx=varargin{1};             % Default value of Ox gate number
        nE=500;                     % Default value of energy values number
    case 2
        nx=varargin{1};             % Default value of Ox gate number
        nE=varargin{2};             % Default value of energy values number
    case 4
        nx=varargin{1};             % Value of Ox gate number
        nE=varargin{2};             % Value of energy values number
        E=linspace(varargin{3},varargin{4},nE);     % Set of energy values
    otherwise
        ('Bad number of optional input arguments!');
end

%% Potential energy

% Construction
x=linspace(0,(Epf-Epi)/slope,nx);       % Spatial domain 
Epc=slope*x+Epi;                        % Linear potential energy (slope en eV/nm)

% Digitalization
[M,xt,Ep]=digitalization(x,Epc);

% Se añade los escalones inicial y final de energía respectiva Epi en x=0
% y Epf en x=(Epf-Epi)/slope
M=['Mi' M 'Mf'];
Ep=[Epi;Ep;Epf];
xt=[0;xt;(Epf-Epi)/slope];

% Energy values
if (length(varargin)~=4 && slope >0)
    E=linspace(Epi,2*Epf,nE);
end    
if (length(varargin)~=4 && slope <0)
    E=linspace(2*Epi,Epf,nE);
end    

%% Reflection and transmission probabilities

[sys,E]=Epot(M,xt,Ep,m,E);          % Fabrication of the system
TES=matrix(sys);

[R,T]=factRT(sys,TES);
graphE(sys,E,T);

return;