function [En,sysfin,Efin,TESfin]=refine(sys,m,En,varargin)
%   REFINE determines the energy of a bound states more precisely. 
%
%   [En,sysfin,Efin,TESfin]=refine(sys,m,En,varargin)
%					-- varargin states for various input arguments
%       >> sys          = System
%       >> m            = Physical object mass
%       >> En           = Bound state energy (to refine)
%       >> varargin     = Optional input arguments
%            > alpha    = Factor (<< 1) such that 2*alpha*En be the new  
%								energetic interval centered on En
%            > nE       = Number of energy values
%            > Emin     = Lowest energy of the new energetic interval
%            > Emax     = Highest energy of the new energetic interval
%       << En           = Refined value of the bound state energy
%       << sysfin       = New system over the new energetic interval 
%       << Efin         = New refined energy values
%       << TESfin       = Transfer matrix of sysfin
%
%   Olivier Pujol (2010)
%
%% System characteristics getting

xt=nan(1,length(sys{1})-1);
Ep=nan(1,length(sys{1}));
M=cell(1,length(sys{1}));

Ep(1)=sys{1}{1}(1);
for ic=2:length(sys{1})
    xt(ic-1)=get(sys{1}{ic},'Position');
    Ep(ic)=get(sys{1}{ic},'OutputPotentialEnergy');
    M{ic-1}=char(get(sys{1}{ic},'Name'));
end

clear sys

%% Optional input arguments

switch length(varargin)
    case 0
        alpha=0.01;                 % Percentage default value 
        nE=400;                     % Default value of energy value number
    case 1
        alpha=varargin{1};          % Percentage default value 
        nE=400;                     % Default value of energy value number
    case 2
        alpha=varargin{1};          % Percentage default value 
        nE=varargin{2};             % Default value of energy value number
    case 3
        Efin=linspace(varargin{1},varargin{2},varargin{3});     % Set of energy values. Origin is at minimum
    otherwise
        ('Bad number of optional input arguments');
end

%% Computing of the refined value of En 

%   Around the approximated value of En, an interval at +/- alpha*En
%   is defined (alpha < 1; default: 0,01).

if (length(varargin)~=3)
    Emin=(1-alpha)*En;
    Emax=(1+alpha)*En;
    Efin=linspace(Emin,Emax,nE);
end

%   The system must be recomputed over the defined interval

[sysfin,Efin]=Epot(M,xt,Ep,m,Efin);
TESfin=matrix(sysfin);
clear M xt En

dfin=nan(1,length(TESfin));         % Initialization
for iT=1:size(TESfin,2)
    dfin(iT)=TESfin{iT}(2,2);       % d-element
end

En=minimum(Efin,dfin);

%% Plotting

figure
plot(log(abs(dfin)),Efin,'b');
axis([min(log(abs(dfin))) max(log(abs(dfin))) min(Efin) max(Efin)]); 
set(gca,'xminortick','on','yminortick','on');
grid on;
box on
title('Zoom on the bound state energy');
xlabel('ln(|d|)');
ylabel('Energy (eV)','Color','k');

return;

function Econf=minimum(Efin,dfin)
%
derivee=diff(log(abs(dfin)));
Ind=derivee(1:end-1).*derivee(2:end) <=0;
Econf=Efin(Ind==1);

return;
